<?php
namespace Teknisa\MAN\Controllers;
use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DTO\Response\Notification;
use Zeedhi\Framework\DataSource;
use Zeedhi\Framework\DataSource\Manager;
use Zeedhi\Framework\DataSource\ParameterBag;
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DataSource\FilterCriteria;
use Teknisa\MAN\Services;
use Zeedhi\Framework\DTO\Response\Message;
use Teknisa\MAN\Utilities;
use Zeedhi\Framework\Controller\CrudWithParameterBag;
use Zeedhi\Framework\DTO\Response\Error;
use Teknisa\MAN\Services\ParamOdhenGoService;

class ParamOdhenGo  extends  CrudWithParameterBag {

    const   errorMessage        = 'Ocorreu um erro inesperado com o serviço de integração. Caso o erro persista, procure o suporte para mais informações',
            dataSourceGeral     = 'paramOdhenGoGeralTab',
            dataSourceFilial    = 'paramOdhenGoFilialTab',
            dataSourcePdv       = 'paramOdhenGoPdvTab',
            dataSourceCaptures  = 'paramOdhenGoCapturesTab';

    protected $utilService,
              $parameterBagGeral    = array('NRORG'),
              $parameterBagFilial   = array('NRORG', 'CDOPERADOR'),
              $parameterBagPdv      = array('CDFILIAL', 'NRORG'),
              $parameterBagCaptures = array('CDFILIAL', 'CDLOJA', 'CDCAIXA', 'NRORG');

    public function __construct ($crudService, $parameterBag, $entityManager, Utilities\Util $utilService, Manager $dataSourceManager, ParamOdhenGoService $ParamOdhenGoService) {
        $this->crudService          = $crudService;
        $this->parameterBag         = $parameterBag;
        $this->entityManager        = $entityManager;
        $this->utilService          = $utilService;
        $this->dataSourceManager    = $dataSourceManager;
        $this->odhenGoService       = $ParamOdhenGoService;
    }

    public function findGeralTab(DTO\Request $request, DTO\Response $response) {
        $this->dataSourceName = self::dataSourceGeral;
        $this->parameterBagColumns = $this->parameterBagGeral;
        parent::find($request, $response);
    }

    public function findFilialTab(DTO\Request $request, DTO\Response $response) {
        $this->dataSourceName = self::dataSourceFilial;
        $this->parameterBagColumns = $this->parameterBagFilial;
        parent::find($request, $response);
    }

    public function findPdvTab(DTO\Request $request, DTO\Response $response) {
        $this->dataSourceName = self::dataSourcePdv;
        $this->parameterBagColumns = $this->parameterBagPdv;
        parent::find($request, $response);
    }

    public function findCapturesTab(DTO\Request $request, DTO\Response $response) {
        $conditions = $this->utilService->getParamsAsArray($request);
        $result = $this->odhenGoService->findCapturesAWS($conditions);
        $response->addDataSet(new DataSet("paramOdhenGoCapturesTab", $result));
        return $response;
    }

    public function findFilesTab(DTO\Request $request, DTO\Response $response) {
        $conditions = $this->utilService->getParamsAsArray($request);
        $result = $this->odhenGoService->findFilesAWS($conditions);
        $response->addDataSet(new DataSet("paramOdhenGoCapturesTab", $result));
        return $response;
    }

    public function saveGeralTab(DTO\Request $request, DTO\Response $response) {
        $conditions = $this->utilService->getParamsAsArray($request);
        $retorno = $this->odhenGoService->saveGeralTab($conditions);
        if(!isset($retorno['HASH']->status)){
            $response->setError(new DTO\Response\Error(self::errorMessage, 500));
        } else {
            return $retorno['UPDATE'];
        }
    }

    public function saveFilialTab(DTO\Request $request, DTO\Response $response) {
        $conditions = $this->utilService->getParamsAsArray($request);
        $retorno = $this->odhenGoService->saveFilialTab($conditions);
        return $retorno;
    }

    public function savePdvTab(DTO\Request $request, DTO\Response $response) {
        $conditions = $this->utilService->getParamsAsArray($request);
        $retorno = $this->odhenGoService->savePdvTab($conditions);
        return $retorno;
    }

    public function getDownloadLink(DTO\Request\Row $request, DTO\Response $response){
        $conditions = $this->utilService->getParamsAsArray($request);
        $retorno = $this->odhenGoService->getDatasetDownloadLink($conditions);
        if(!$retorno['STATUS']){
            $response->setError(new DTO\Response\Error(self::errorMessage, 500));
        } else {
            $response->addDataSet(new DataSet("paramOdhenGoGetDownloadLink", $retorno));
            return $response;
        }
    }
}